# Changelog

## 0.1.0-alpha.2 (2025-06-25)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/babelcloud/gbox-sdk-py/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([1a97852](https://github.com/babelcloud/gbox-sdk-py/commit/1a9785208550d2233505c115ba245a972762e9c1))
* **api:** api update ([df5dfee](https://github.com/babelcloud/gbox-sdk-py/commit/df5dfee51f249af27ea1f2cc9a0b02a80ba2c199))
* **api:** api update ([3da7479](https://github.com/babelcloud/gbox-sdk-py/commit/3da7479394855329abb7c747f378ed0347bdb291))
* **api:** api update ([784ca67](https://github.com/babelcloud/gbox-sdk-py/commit/784ca673d73d1e651a021787b4f5e0f6eb0da939))
* **api:** api update ([f371a5d](https://github.com/babelcloud/gbox-sdk-py/commit/f371a5d0fe10450dc19c5fd59d34ca7ecf6e6311))
* **api:** api update ([9105104](https://github.com/babelcloud/gbox-sdk-py/commit/9105104f2b5d1436b669702c9bb219d9a906c996))
* **api:** api update ([8133a2e](https://github.com/babelcloud/gbox-sdk-py/commit/8133a2eb0e80f03d24a5f8c473dac44cde0b952e))
* **api:** api update ([a3ee1c8](https://github.com/babelcloud/gbox-sdk-py/commit/a3ee1c81a53defc05d10c805333158076e1dee9e))
* **api:** api update ([90f9822](https://github.com/babelcloud/gbox-sdk-py/commit/90f9822d821b244786cd6ce0a2f3a0829b61e9e9))
* **api:** api update ([002833a](https://github.com/babelcloud/gbox-sdk-py/commit/002833ad9c955c670cfc1d3ec3164f8cf15a7625))
* **api:** api update ([bbe9346](https://github.com/babelcloud/gbox-sdk-py/commit/bbe9346f8f29518230ee5e68d6c1d9ac1280000a))
* **api:** api update ([62a2c4b](https://github.com/babelcloud/gbox-sdk-py/commit/62a2c4b1ab5a2990a0982620e53c27967a8a0bbf))
* **api:** api update ([5755604](https://github.com/babelcloud/gbox-sdk-py/commit/575560487caff6e1c0b323f71b1aa4d9decf2ca8))
* **api:** api update ([e151cf3](https://github.com/babelcloud/gbox-sdk-py/commit/e151cf3085785bfb9adde4f1717658d2ab9df725))
* **api:** api update ([12d4278](https://github.com/babelcloud/gbox-sdk-py/commit/12d4278f0fe3a7c669443e74a5e6c1462355db8a))
* **api:** api update ([9ad1d28](https://github.com/babelcloud/gbox-sdk-py/commit/9ad1d283116f9d15d32a0567b499380a1d49a432))
* **api:** api update ([1829e97](https://github.com/babelcloud/gbox-sdk-py/commit/1829e97c1644c31b3a1b658b67a9b7a556141253))
* **api:** api update ([af01124](https://github.com/babelcloud/gbox-sdk-py/commit/af01124f751920d072c485ba87bbb4234fd5203f))
* **api:** api update ([1e313ed](https://github.com/babelcloud/gbox-sdk-py/commit/1e313ed95b981c6751066167c5283780058fbb42))
* **api:** api update ([0361074](https://github.com/babelcloud/gbox-sdk-py/commit/0361074903fab99a6f3d2eb129d0b7a193d2cfbd))
* **api:** api update ([89eb38e](https://github.com/babelcloud/gbox-sdk-py/commit/89eb38e1de1df468c281efe0b8ed0c207587cc8a))
* **api:** api update ([3a428f4](https://github.com/babelcloud/gbox-sdk-py/commit/3a428f43b0af327d78160c20a67f4e6f6fe63608))
* **api:** api update ([55ac95e](https://github.com/babelcloud/gbox-sdk-py/commit/55ac95ee15183da8f6550998ab71e45decc8bb74))
* **api:** api update ([bab02cb](https://github.com/babelcloud/gbox-sdk-py/commit/bab02cba5c4bc934278b8103e9629bda225c409f))
* **api:** api update ([bae1c5c](https://github.com/babelcloud/gbox-sdk-py/commit/bae1c5c5338e272ac51728ae0d2eb82f668f273f))
* **api:** api update ([32245ed](https://github.com/babelcloud/gbox-sdk-py/commit/32245edcc14eb4e4552942b9e4781833610a54a6))
* **api:** api update ([0cee4a7](https://github.com/babelcloud/gbox-sdk-py/commit/0cee4a7bf0b4801e99792375e9075fbb61755825))
* **api:** api update ([39ab273](https://github.com/babelcloud/gbox-sdk-py/commit/39ab2736256da51ceef7fd72bf87736ebcd856e1))
* **api:** api update ([9b8d6f8](https://github.com/babelcloud/gbox-sdk-py/commit/9b8d6f8958e7f9e3122996298496c947250f3e9e))
* **api:** api update ([462b313](https://github.com/babelcloud/gbox-sdk-py/commit/462b3138f408b784c3ea1fe931db8ed2ef123a9a))
* **api:** api update ([874fb44](https://github.com/babelcloud/gbox-sdk-py/commit/874fb446e1c59d6b17a4c49961c9435a933e61b6))
* **api:** api update ([1ce6554](https://github.com/babelcloud/gbox-sdk-py/commit/1ce6554bba010bc002b490f8baa485b7641b69e5))
* **api:** api update ([55a6d7d](https://github.com/babelcloud/gbox-sdk-py/commit/55a6d7d0e9a46ff993f4f5732be41280656000aa))
* **api:** api update ([75bfcde](https://github.com/babelcloud/gbox-sdk-py/commit/75bfcde9fea96fa035f47367054946a68ea48d34))
* **api:** api update ([1c41908](https://github.com/babelcloud/gbox-sdk-py/commit/1c419083685302a991156bc50148862299383ce0))
* **api:** api update ([33d8679](https://github.com/babelcloud/gbox-sdk-py/commit/33d86797f41da3fc8dd5e255697bd3545cafcad5))
* **api:** api update ([f568c85](https://github.com/babelcloud/gbox-sdk-py/commit/f568c857299cb093c000c2a862192d960ebc1bbd))
* **api:** api update ([9b6f9de](https://github.com/babelcloud/gbox-sdk-py/commit/9b6f9de4aec8c06f7656e56f680079e5959e40f8))
* **api:** api update ([f6fb04b](https://github.com/babelcloud/gbox-sdk-py/commit/f6fb04b5e56de779bb2cc829bbf56966b8b1749b))
* **api:** api update ([975884c](https://github.com/babelcloud/gbox-sdk-py/commit/975884ce6f565dbcd1829028ae7ad5d20dc5bcec))
* **api:** api update ([e3badb0](https://github.com/babelcloud/gbox-sdk-py/commit/e3badb0a6e72f48f3b75897db9bd24f453fcb1bd))
* **api:** api update ([568484b](https://github.com/babelcloud/gbox-sdk-py/commit/568484b9961d267466c382ec36c30b9fac558425))
* **api:** api update ([3277243](https://github.com/babelcloud/gbox-sdk-py/commit/32772434884f859363eee941fbf6d8238cbfb36d))
* **api:** api update ([8cc0a38](https://github.com/babelcloud/gbox-sdk-py/commit/8cc0a38268abaa14acf21d00f9681e35e7869a27))
* **api:** api update ([9029aab](https://github.com/babelcloud/gbox-sdk-py/commit/9029aabb651500a65bbd81d9dc6726627b859180))
* **api:** api update ([8c641f4](https://github.com/babelcloud/gbox-sdk-py/commit/8c641f470a37badd59a53778cb328a440fad50bc))
* **api:** api update ([a820b3f](https://github.com/babelcloud/gbox-sdk-py/commit/a820b3fa2609846515b43a2e6875405a784e2ed2))
* **api:** api update ([4280a67](https://github.com/babelcloud/gbox-sdk-py/commit/4280a67ad066fa691fdf06689adc42cf818e588d))
* **api:** api update ([5a3e3ce](https://github.com/babelcloud/gbox-sdk-py/commit/5a3e3ce9d0f8e058bf168e36a35e673c7fbcc2b3))
* **api:** api update ([f91642f](https://github.com/babelcloud/gbox-sdk-py/commit/f91642f964a2e51647cb054977bedc665d6923e9))
* **api:** api update ([f4efa25](https://github.com/babelcloud/gbox-sdk-py/commit/f4efa25622088a1cfe2fa2187c1d8090368fc3e7))
* **api:** api update ([481f354](https://github.com/babelcloud/gbox-sdk-py/commit/481f35440439916da2836659fdf125086ce12a20))
* **api:** api update ([81beaf6](https://github.com/babelcloud/gbox-sdk-py/commit/81beaf6636b3c250255de43068835ca1a7b7dd95))
* **api:** api update ([4eba864](https://github.com/babelcloud/gbox-sdk-py/commit/4eba8647159e65cd74dfb385f2d958182331eb4a))
* **api:** api update ([cdb0e97](https://github.com/babelcloud/gbox-sdk-py/commit/cdb0e97c8cf191b36a9bf76724db4be676832e64))
* **api:** api update ([7c07d26](https://github.com/babelcloud/gbox-sdk-py/commit/7c07d269a33cb90759d90344e46490408dd822d3))
* **api:** api update ([5cf58a9](https://github.com/babelcloud/gbox-sdk-py/commit/5cf58a901471fce9dca71356b6e23aac91c02bdd))
* **api:** api update ([abe1ca5](https://github.com/babelcloud/gbox-sdk-py/commit/abe1ca5e7e29ba9cb802c52ddf961a71779216fd))
* **api:** api update ([5cce3d5](https://github.com/babelcloud/gbox-sdk-py/commit/5cce3d5b4f7bac209a59c466f196ab46424ed77b))
* **api:** api update ([1dbccff](https://github.com/babelcloud/gbox-sdk-py/commit/1dbccff9140302900f1de07e168421b889b4ed1f))
* **api:** api update ([78e2d17](https://github.com/babelcloud/gbox-sdk-py/commit/78e2d17e5d1620c6542bf934dcfd8305bc8456eb))
* **api:** api update ([7b3e36f](https://github.com/babelcloud/gbox-sdk-py/commit/7b3e36f84004f5a7ea7513dec28730cef8f9728e))
* **api:** api update ([17dbf3a](https://github.com/babelcloud/gbox-sdk-py/commit/17dbf3aa1d6aed4cc9b8ca574ec4f9018b96648e))
* **api:** api update ([56c90f3](https://github.com/babelcloud/gbox-sdk-py/commit/56c90f37772161878298a96e57163afd5f7165a7))
* **api:** api update ([26b0d82](https://github.com/babelcloud/gbox-sdk-py/commit/26b0d8254192669ff10804e51b9935c5af8ddf9f))
* **api:** api update ([f149278](https://github.com/babelcloud/gbox-sdk-py/commit/f1492784c839c750788bdda7a8225bb7f9c72641))
* **api:** api update ([a919aaf](https://github.com/babelcloud/gbox-sdk-py/commit/a919aaf379961c1b7bf3a9d4b16ea716b4857d36))
* **api:** api update ([33de52f](https://github.com/babelcloud/gbox-sdk-py/commit/33de52f43e0f71747ecea3171e8445127904c5a6))
* **api:** api update ([5fe515c](https://github.com/babelcloud/gbox-sdk-py/commit/5fe515c987e40ba6eeada913a9cecff5159cfb33))
* **api:** api update ([0991e0e](https://github.com/babelcloud/gbox-sdk-py/commit/0991e0e88081a6fcbb4cec70a6d92b481f5f9019))
* **api:** api update ([5c1b649](https://github.com/babelcloud/gbox-sdk-py/commit/5c1b649de6650f639dc6723985c293474f477871))
* **api:** api update ([bf932a1](https://github.com/babelcloud/gbox-sdk-py/commit/bf932a145e86dd9d650ca8b221783b97779eeb16))
* **api:** api update ([21423ce](https://github.com/babelcloud/gbox-sdk-py/commit/21423ce58b68b4132947c561f0b6a72facbb1e4f))
* **api:** api update ([516f187](https://github.com/babelcloud/gbox-sdk-py/commit/516f18737316cde5715adac83bebc2c136116f14))
* **api:** api update ([e634222](https://github.com/babelcloud/gbox-sdk-py/commit/e63422205b3a2b7d53c73775b60a8784a33fdb3d))
* **api:** api update ([8b53b53](https://github.com/babelcloud/gbox-sdk-py/commit/8b53b53cf89837d0b49761d09b84fd41dcb7f028))
* **api:** api update ([623b01c](https://github.com/babelcloud/gbox-sdk-py/commit/623b01c6fb6396ec952d7271b2039ec592b62631))
* **api:** api update ([b866218](https://github.com/babelcloud/gbox-sdk-py/commit/b8662185a6544fa80b57496a8a38540ca178960e))
* **api:** api update ([e9775fd](https://github.com/babelcloud/gbox-sdk-py/commit/e9775fd99203595149e9621d44a76e49ff4a2f7e))
* **api:** api update ([3df4a6f](https://github.com/babelcloud/gbox-sdk-py/commit/3df4a6f58c2908e0204835bc13ef48cb31312091))
* **api:** api update ([03ecf6c](https://github.com/babelcloud/gbox-sdk-py/commit/03ecf6c7204bab91c7994d613584206960eaf552))
* **api:** api update ([288ce1b](https://github.com/babelcloud/gbox-sdk-py/commit/288ce1be34525d6be88e5dd0367e21c1f8b2a84b))
* **api:** api update ([245aad5](https://github.com/babelcloud/gbox-sdk-py/commit/245aad5e47e70291c2060e5b7fff6f1ce211ce53))
* **api:** api update ([550cdde](https://github.com/babelcloud/gbox-sdk-py/commit/550cdde72c20c3768ea333b4e4aef27dd9532ec4))
* **api:** api update ([a88dcb9](https://github.com/babelcloud/gbox-sdk-py/commit/a88dcb9bddd7466f1fd45f689203bc6446982fed))
* **client:** add support for aiohttp ([0a37597](https://github.com/babelcloud/gbox-sdk-py/commit/0a37597d3fded81a7cfa68c11282dadc913c1714))


### Bug Fixes

* **client:** correctly parse binary response | stream ([d1f8ffd](https://github.com/babelcloud/gbox-sdk-py/commit/d1f8ffd38e37ab8a990060d2a68057620eac6f04))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([b3d0d94](https://github.com/babelcloud/gbox-sdk-py/commit/b3d0d946c992a233ee49f235c8b5a9f567bcd58a))


### Chores

* **ci:** enable for pull requests ([6ae6987](https://github.com/babelcloud/gbox-sdk-py/commit/6ae6987d2acefdadf1730fd50f07fdf389fdfcec))
* **internal:** codegen related update ([e41dafb](https://github.com/babelcloud/gbox-sdk-py/commit/e41dafb5a91a92dd2928329a8dc8856e993df1e4))
* **internal:** codegen related update ([e456265](https://github.com/babelcloud/gbox-sdk-py/commit/e45626561d64a49165d9c916f84ce1e9b478b1b1))
* **internal:** codegen related update ([b109699](https://github.com/babelcloud/gbox-sdk-py/commit/b1096998c433bccb68f6f5b7db7a9ab5de355c4a))
* **internal:** codegen related update ([188ca86](https://github.com/babelcloud/gbox-sdk-py/commit/188ca86542c348ae33ea47fd341b4704d5ecc5f5))
* **internal:** codegen related update ([32504d2](https://github.com/babelcloud/gbox-sdk-py/commit/32504d237ec70e40a25f235488d41f9280354239))
* **internal:** update conftest.py ([f9e6b54](https://github.com/babelcloud/gbox-sdk-py/commit/f9e6b541e32ba6f22a007314ceb109707e2b3946))
* **readme:** update badges ([1193cf7](https://github.com/babelcloud/gbox-sdk-py/commit/1193cf7faa1322dfc40ceecd038d33422e17b986))
* sync repo ([8af8cc9](https://github.com/babelcloud/gbox-sdk-py/commit/8af8cc90cb15e76c69bab846c6b42b0e53c9a3f7))
* **tests:** add tests for httpx client instantiation & proxies ([657c898](https://github.com/babelcloud/gbox-sdk-py/commit/657c898c2b5562ec0a5a2e1683953ef6042e5845))
* **tests:** run tests in parallel ([6fb47d9](https://github.com/babelcloud/gbox-sdk-py/commit/6fb47d9b3026fcd22aa85658f560c41f0606edeb))
* **tests:** skip some failing tests on the latest python versions ([406d869](https://github.com/babelcloud/gbox-sdk-py/commit/406d86938ace6237b8b3184d055281a287de4d2a))
* update SDK settings ([2878195](https://github.com/babelcloud/gbox-sdk-py/commit/28781951f41aa7685e2ace74c8d2de4f8229ead9))
* update SDK settings ([d43dfa9](https://github.com/babelcloud/gbox-sdk-py/commit/d43dfa932601b4ce7a92de8efc9e99a75ddfc248))
* update SDK settings ([11153e3](https://github.com/babelcloud/gbox-sdk-py/commit/11153e337cdfbeb0e0d87c7820792def3e825148))
* update SDK settings ([ef449ed](https://github.com/babelcloud/gbox-sdk-py/commit/ef449ed6db430163109f97be235486d394095f60))
* update SDK settings ([b77e532](https://github.com/babelcloud/gbox-sdk-py/commit/b77e5324a253b54bed8a2dcd640f12260f54dbb2))
* update SDK settings ([5abe7e2](https://github.com/babelcloud/gbox-sdk-py/commit/5abe7e216d3a0f57f9a81a8ac1f9e7a3987b4a97))
* update SDK settings ([655240f](https://github.com/babelcloud/gbox-sdk-py/commit/655240fdf09565118c2bae6ad3009708871f2380))
* update SDK settings ([fe88869](https://github.com/babelcloud/gbox-sdk-py/commit/fe8886987378d53a5eba80f9d6787fcb59c78653))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([5dc09c6](https://github.com/babelcloud/gbox-sdk-py/commit/5dc09c6358512e9ba5b31c36bcff876f83323e76))
